@@ -447,7 +447,7 @@ class GUI(Tk):
 			self.make_keys() # Just in case
 			if self.display:
 				self.dump_config()
-			if self.cfg['audio_format'] is not 'Piano':
+			if self.cfg['audio_format'] == 'MIDI' or self.cfg['audio_format'].endswith('.sf2'):
 				fn_midi = os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.mid'
 				fn_wav = os.path.join(self.cfg['save_path'],self.cfg['file_out'])+'.wav'
 				MIDI = MIDIFile(1)  # One track
@@ -456,10 +456,10 @@ class GUI(Tk):
 					# addNote(track, channel, pitch, time + i, duration, volume)
 					MIDI.addNote(0, 0, self.nd['note'][j], self.nd['st'][j], (self.nd['en'][j]-self.nd['st'][j]), self.nd['mag'][j])
 				with open(fn_midi, 'wb') as mid:
-					MIDI.writeFile(mid)
-				if self.cfg['audio_format'].endswith('.sf2'):
-					fn_sf = os.path.join(self.cfg['save_path'],'anthem_soundfonts',self.cfg['audio_format'])
-					os.system('fluidsynth -ni -F {} -r 44100 {} {}'.format(fn_wav,fn_sf,fn_midi))
+					MIDI.writeFile(mid)		
+			if self.cfg['audio_format'].endswith('.sf2'):
+				fn_font = os.path.join(self.package_path,'anthem_soundfonts',self.cfg['audio_format'])
+				os.system('fluidsynth -ni -F {} -r 44100 {} {}'.format(fn_wav,fn_font,fn_midi))
 			elif self.cfg['audio_format'] == 'Piano':
 				self.synth()
 			elif self.cfg['audio_format'] == 'Stream':
